@@ -18,7 +18,7 @@ def executor_wrapper(obj, func_name):
         try:
             result = func(*args, **kwargs)
         except Exception as e:
-            return False, error_msg.format(type(obj), obj, func.__name__, e)
+            return False, error_msg.format(type(obj), obj, func.__name__, e.with_traceback())
         # todo: 正常返回时，增加对应的obj信息
         return True, result
 
